%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1); % save pic flag
fontsz = 10;

R = 287.05; % J/(Kg K)
lbd = 6400; % Angstrom
k = 3600*180/pi;

s = 1/lbd;

load 'data\f03\rds.mat'
% rdstms rdsval (cell)
% edtval_tmp edtval_tem edtval_rhu edtval_hgt edtval_prs edtval_dew
% edtval_mxr edtval_deg edtval_spd edtval_rng edtval_lon edtval_lat

strdy = datenum([2011 02 27]);
enddy = datenum([2011 02 29]);
stre = datenum([2011 02 01]);
ende = datenum([2011 03 16]);

hi = [14:5:20004];

ps = find(rdstms>stre & rdstms<ende);
for i=1:length(ps)
    rdsvas{i} = rdsval{ps(i)};
end
rdstms = rdstms(ps);
psdy = find(rdstms>strdy & rdstms<enddy);

for i=1:length(rdstms)
    
    aux = rdsvas{i};
    tmp{i} = aux(:,1);
    tem{i} = aux(:,2);
    rhu{i} = aux(:,3);
    hgt{i} = aux(:,4);
    prs{i} = aux(:,5);
    dew{i} = aux(:,6);
    mxr{i} = aux(:,7);
    deg{i} = aux(:,8);
    spd{i} = aux(:,9);
    
    ri(i) = max(aux(:,3));
    if max(aux(:,3))>95 continue; end
    
    % wind direction radians
    rad{i} = deg{i}*pi/180;
    % air density
    rho{i} = prs{i}*1E+2 ./ (R*tem{i});
    % dynamic viscosity
    muv{i} = 0.1456*1E-5*(sqrt(tem{i})./(1+110./tem{i}));
    
    % means
    rhoi = rho{i};
    rhm{i} = (rhoi(2:end)+rhoi(1:end-1))/2;
    muvi = muv{i};
    mum{i} = (muvi(2:end)+muvi(1:end-1))/2;
    
    % wind speed shear
    spdx = spd{i}.*cos(rad{i});
    spdy = spd{i}.*sin(rad{i});
    dspx = (spdx(2:end)-spdx(1:end-1));
    dspy = (spdy(2:end)-spdy(1:end-1));
    dsp{i} = sqrt(dspx.^2+dspy.^2);
    spdi = spd{i};
    % wind mean
    spm{i} = (spdi(2:end)+spdi(1:end-1))/2;
    
    % altitude mean and steps
    hgti = hgt{i};
    hgm{i} = (hgti(2:end)+hgti(1:end-1))/2;
    hgd{i} = (hgti(2:end)-hgti(1:end-1));
    
    % mixing ratio
    mxri = mxr{i};
    mxm{i} = (mxri(2:end)+mxri(1:end-1))/2;
    % temperature
    temi = tem{i};
    tmm{i} = (temi(2:end)+temi(1:end-1))/2;
    tmd{i} = abs(temi(2:end)-temi(1:end-1));
    
    % see Owens 1967 (refraction index) page 56 left
    Ds = prs{i}./tem{i}.*(1 + prs{i}.*(57.90*1E-8-9.3250*1E-4./tem{i}+0.25844./tem{i}.^2));
    Dw = prs{i}.*mxr{i}./tem{i}.*(1 + prs{i}.*mxr{i}.*(1+3.7*1E-4*prs{i}.*mxr{i}).*(-2.37321*1E-3+2.23366./tem{i}-710.792./tem{i}.^2+7.75141*1E+4./tem{i}.^3));
    psa = (2371.34+683939.7/(130-s^2)+4547.3/(38.9-s^2))*Ds;
    pwa = (6487.31+58.058*s^2-0.71150*s^4+0.08851*s^6)*Dw;
    n{i} = 1+(psa+pwa)*1E-8;
    % means
    ni = n{i};
    nd{i} = abs(ni(2:end)-ni(1:end-1));
    nm{i} = (ni(2:end)+ni(1:end-1))/2;
    
    % Full width at half maximum
%     se{i} = 2.355*((nm{i}.^1-1).*dsp{i}./spm{i}.*tmd{i})*k;
    se{i} = k*dsp{i}./spm{i}.*nd{i}*6;
    fw{i} = flipud(sqrt(cumsum(flipud(se{i}).^2)));
    
    vec = interp1(hgm{i},se{i},hi);
    vec(isnan(vec)) = 0;
    nbs = double(vec>0);
    sev(i,:) = vec;
    sen(i,:) = nbs;
    vec = interp1(hgm{i},fw{i},hi);
    vec(isnan(vec)) = 0;
    nbs = double(vec>0);
    fwv(i,:) = vec;
    fwn(i,:) = nbs;
    
end

sem = sum(sev)./sum(sen);
fwm = sum(fwv)./sum(fwn);
for i=1:length(hi)
    vec = sev(:,i);
    sed(i) = median(vec);
    vec = fwv(:,i);
    fwd(i) = median(vec);
end



fig1=figure(2);
clf reset

fig2.Renderer='Painters';

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.12 .1],[.19 .035],[.13 .01]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 8.3; height = 5; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz-2)

loglog(fw{1},hgm{1}*nan,':','LineWidth',0.25)
hold on
loglog(fwm,hi*nan,'-g','LineWidth',1)
loglog(fwd,hi*nan,'-r','LineWidth',1)
loglog(fw{psdy(1)},hgm{psdy(1)}*nan,'-k','LineWidth',1)
loglog(fw{psdy(2)},hgm{psdy(2)}*nan,'--k','LineWidth',1)
loglog([0.01 100],[610 610]*nan,'-m','LineWidth',1)

for i=1:length(rdstms)
    loglog(fw{i},hgm{i},':b','LineWidth',0.25)
end
loglog(fwm,hi,'-g','LineWidth',1)
loglog(fwd,hi,'-r','LineWidth',1)
loglog(fw{psdy(1)},hgm{psdy(1)},'-k','LineWidth',1)
loglog(fw{psdy(2)},hgm{psdy(2)},'--k','LineWidth',1)
loglog([0.01 100],[610 610],'-m','LineWidth',1)
set(gca,'YLim',[10 10000],'XLim',[0.01 30])
hold off

lg1 = legend([datestr(rdstms(1),'YYYY/mm/dd'),'-',datestr(rdstms(end),'mm/dd')],...
    'mean','median',datestr(rdstms(psdy(1)),'YYYY/mm/dd HH:MM'),datestr(rdstms(psdy(2)),'YYYY/mm/dd HH:MM'),'location','southwest');
% set(lg1,'FontSize',fontsz-3.5)
lgps = get(lg1,'position');
lgps(1) = lgps(1)-0.06;
lgps(2) = lgps(2)-0.11;
set(lg1,'FontSize',fontsz-3,'position',lgps,'Color','w','Interpreter','latex')

xlabel('$\omega$ ($^{\prime\prime}$)','FontSize',fontsz,'Interpreter','latex')
ylabel('Altitude (m)','FontSize',fontsz,'Interpreter','latex')
% text(10,850,'\color{magenta}RidgeLab (610m)','FontSize',fontsz-3)
text(0.012,750,'Ridge Lab (610m)','FontSize',fontsz-3,'Interpreter','latex')
% set(gca,'XTick',[1,2,3:2:13])
% set(gca,'YTick',[0.001 0.01 0.1])
% set(gca,'YTickLabel',num2str([0.001 0.01 0.1]'))
set(gca,'FontSize',fontsz-2)
grid on
set(gca,'FontName','times')

outfile1 = strcat('pics/png/','fig03');
% outfile2 = strcat('pics/eps/','fig03');
% outfile3 = strcat('pics/tif/','fig03');
outfile4 = strcat('pics/pdf/','fig03');

if flg
    print('-dpng', '-r400', [outfile1,'.png'])
%     print('-depsc2', '-tiff','-painters', '-r400', [outfile2,'.eps'])
%     print('-dtiff', '-r400', [outfile3,'.tif'])
    print('-Painters','-dpdf', '-r400', [outfile4,'.pdf'])
%     print('-dpdf', '-r400', [outfile4,'.pdf'])
end



