%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')
% opengl('save', 'software')

flg = logical(1); % save pic flag
fontsz = 10;

load 'data\f06\cals.mat' WL
WL = WL*1000;

% HR 7001      HR 2491
% load 'calspec-hst\calspec.mat' stahst wmdorg fmdorg whtorg fhtorg wavhst flm050 flh050 flm075 flh075 flm100 flh100
load 'data\f06\calspecs.mat' 
% wmdveg fmdveg whtveg fhtveg wmdsir fmdsir whtsir fhtsir wavhst stahst flm050 flh050 flm075 flh075 flm082 flh082 flm100 flh100

w0 = whtveg;
w2 = wavhst;

f0 = interp1(w0,fhtveg,w2);

m0 = -2.5*log(fhtveg*1E+8);
m1 = -2.5*log(flh050(1,:)*1E+8);
m2 = -2.5*log(flh082(1,:)*1E+8);
m3 = -2.5*log(flh100(1,:)*1E+8);

m2b = (m1+2*m3)/3;

c0 = interp1(w0,m0,WL);
c1 = interp1(w2,m1,WL);
c2 = interp1(w2,m2,WL);
c3 = interp1(w2,m3,WL);

c2b = interp1(w2,m2b,WL);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.11 .1],[.09 .045],[.125 .025]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.4; height = 1.4*9; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));

plot(w0,m0,'k')
hold on
plot(w2,m1,'b')
plot(w2,m2,'r')
plot(w2,m3,'g')
plot(WL,c0,'ok','MarkerFaceColor',[1 1 1],'LineWidth',1)
plot([WL(1) WL(1)],[0.4 1.4],':k')
hold off
set(gca,'YLim',[0.4 1.4])
set(gca,'XLim',[405 440])
text(405.3,1.335,'(a)','FontSize',fontsz+2,'Interpreter','latex')

h = legend('1 \AA ~resolution','5 nm FWHM','8.2 nm FWHM','10 nm FWHM','location','southeast');
lgps = get(h,'position');
lgps(1) = lgps(1)+0.03;
lgps(2) = lgps(2)-0.022;
set(h,'FontSize',fontsz-1,'position',lgps,'Color','w','Interpreter','latex')

yh = ylabel('$M_0$','FontSize',fontsz+2);
set(yh,'Interpreter','latex');
xh = xlabel('Wavelength (nm)','FontSize',fontsz+2);
set(xh,'Interpreter','latex');

set(gca,'FontName','times','FontSize',fontsz+1)
title('HR 7001 (Vega, A0Va) spectrum @bandpass (marker=channel)','FontWeight','normal','FontSize',fontsz+1,'Interpreter','latex')

axes(ha(2));
set(gca,'FontSize',fontsz)

plot(w2,m2-m3,'b')
hold on
plot(w2,-(m2-m1),'r')
plot(w2,(m2-m2b),'k')
plot(WL,c2-c3,'ob','MarkerFaceColor',[1 1 1],'LineWidth',1)
plot(WL,-(c2-c1),'or','MarkerFaceColor',[1 1 1],'LineWidth',1)
plot(WL,(c2-c2b),'ok','MarkerFaceColor',[1 1 1],'LineWidth',1)
plot([400 1050],[0.02 0.02],'-k')
plot([400 1050],[-0.02 -0.02],'-k')
plot([735 735],[-0.08 0.08],'k')
set(gca,'YGrid','on')
hold off
set(gca,'YLim',[-0.06 0.06])
set(gca,'XLim',[400 1050])
text(405,0.052,'(b)','FontSize',fontsz+2,'Interpreter','latex')

yh = ylabel('$\delta M_0$','FontSize',fontsz+2);
set(yh,'Interpreter','latex');
xh = xlabel('Wavelength (nm)','FontSize',fontsz+2);
set(xh,'Interpreter','latex');
h = legend('$M_{\mathrm{8.2}}-M_{\mathrm{10}}$','$M_{\mathrm{5.0}}-M_{\mathrm{8.2}}$','$M_{\mathrm{8.2}} - (M_{\mathrm{5.0}}+2M_{\mathrm{10}})/3$','location','north');
lgps = get(h,'position');
lgps(1) = lgps(1)+0.02;
lgps(2) = lgps(2)+0.02;
set(h,'FontSize',fontsz-1,'position',lgps,'Color','w','Interpreter','latex')
set(gca,'YTick',[-0.06:0.02:0.06])
set(gca,'FontName','times','FontSize',fontsz+1)

outfile2 = strcat('pics/png/','fig06');
outfile5 = strcat('pics/pdf/','fig06');


if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end

