%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1); % save pic flag
fontsz = 11;

load 'data\f08\spdrf7001.mat' tms wv pe sp

t0 = datenum([2018 02 15]);

dtms = tms-t0;
dt = 1:1000;
for i=1:6
    dd = wv(:,i)-mean(wv(:,i));
    p = polyfit(dtms,dd',3);
    ft = p(1)*dt.^3+p(2)*dt.^2+p(3)*dt+p(4);
%     p = polyfit(dtms,dd',2);
%     ft = p(1)*dt.^2+p(2)*dt+p(3);
    dwvs(:,i) = dd';
    dfts(:,i) = ft;
end

figure(20)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.12 .1],[.185 .01],[.11 .035]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 6; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));
set(gca,'FontSize',fontsz-2)

plot(dtms,wv(:,1)-wv(1,1)*nan,'o-k','LineWidth',0.5,'MarkerSize',3)
hold on
plot(dtms,wv(:,2)-wv(1,2)*nan,'d--k','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,3)-wv(1,3)*nan,'s-.k','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,4)-wv(1,4)*nan,'p:k','LineWidth',0.5,'MarkerSize',4)
plot(dtms,wv(:,5)-wv(1,5)*nan,'o-b','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,6)-wv(1,6)*nan,'o-r','LineWidth',0.5,'MarkerSize',3)

plot(dtms,wv(:,1)-mean(wv(:,1)),'ok','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,2)-mean(wv(:,2)),'dk','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,3)-mean(wv(:,3)),'sk','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,4)-mean(wv(:,4)),'pk','LineWidth',0.5,'MarkerSize',4)
plot(dtms,wv(:,5)-mean(wv(:,5)),'ob','LineWidth',0.5,'MarkerSize',3)
plot(dtms,wv(:,6)-mean(wv(:,6)),'or','LineWidth',0.5,'MarkerSize',3)

plot(dt,dfts(:,1),'-k','LineWidth',1)
plot(dt,dfts(:,2),'--k','LineWidth',1)
plot(dt,dfts(:,3),'-.k','LineWidth',1)
plot(dt,dfts(:,4),':k','LineWidth',1)
plot(dt,dfts(:,5),'-b','LineWidth',1)
plot(dt,dfts(:,6),'-r','LineWidth',1)
hold off

set(gca,'XLim',[0 1000],'YLim',[-0.45 0.26])
set(gca,'YTick',[-0.4:0.2:0.4])

lg1 = legend(['$H_{\delta}$ = ',num2str(sp(1),'%4.1f'),' nm'],...
    ['$H_{\gamma}$ = ',num2str(sp(2),'%4.1f'),' nm'],...
    ['$H_{\beta}$ = ',num2str(sp(3),'%4.1f'),' nm'],...
    ['$H_{\alpha}$ = ',num2str(sp(4),'%4.1f'),' nm'],...
    ['$O_2$ = ',num2str(sp(5),'%4.1f'),' nm'],['$H_2O$ = ',num2str(sp(6),'%4.1f'),' nm'],'location','south');
set(lg1,'color','w','FontSize',fontsz-2,'Interpreter','latex')

lgps = get(lg1,'position');
lgps(1) = lgps(1)-0.0;
lgps(2) = lgps(2)-0.04;
set(lg1,'position',lgps)

ylabel('$\Delta\lambda$ (nm), HR 7001','FontSize',fontsz+1,'Interpreter','latex')
xlabel(['Number of days from ',datestr(t0,'yyyy-mmm-dd'),', up to ',datestr(tms(end),'yyyy-mmm-dd')],'FontSize',fontsz+1,'Interpreter','latex')
set(gca,'FontSize',fontsz-2)

grid on
set(gca,'FontName','times','FontSize',fontsz)

outfile1 = strcat('pics/png/','fig08');
outfile4 = strcat('pics/pdf/','fig08');

if flg
    print('-dpng', '-r400', [outfile1,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile4,'.pdf'])
end