%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')
% opengl('save', 'software')

flg = logical(1); % save pic flag
fontsz = 10;


load 'data\f09\cals.mat' WL
WL = WL*1000;

% HR 7001      HR 2491
load 'data\f09\calspecs.mat' 
% wmdveg fmdveg whtveg fhtveg wmdsir fmdsir whtsir fhtsir wavhst stahst flm050 flh050 flm075 flh075 flm082 flh082 flm100 flh100

w2 = wavhst;
m2 = -2.5*log10(flh082(1,:)*1E+8);
c2 = interp1(w2,m2,WL);

mt = zeros(21,length(m2));
mt(11,:) = m2*0;
% wt = mt;
for i=1:10
    mt(11-i,:) = [m2(1:end-i)-m2(1+i:end),repmat(nan,1,i)];
    mt(i+11,:) = [repmat(nan,1,i),m2(1+i:end)-m2(1:end-i)];
end
smt = sum(mt);
ps = find(~isnan(smt));
ww = w2(ps);
mt = mt(:,ps);

mc = zeros(21,length(WL));
for i=1:21
    mc(i,:) = interp1(ww,mt(i,:),WL);
end
mc(11,:) = mc(11,:)*0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%55

figure(2)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.02 .1],[.19 .01],[.13 .01]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 0.6*10; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));
set(gca,'FontSize',fontsz)

plot(w2,m2,'-k')
hold on
plot(WL,c2,'ob','LineWidth',1)
hold off

set(gca,'XLim',[400 1050],'YLim',[-0.5 4.5])

h = legend(['HR 7001 spectrum'],'nominal channels','location','southeast');
lgps = get(h,'position');
lgps(1) = lgps(1)+0.025;
lgps(2) = lgps(2)-0.04;
set(h,'FontSize',fontsz-1,'position',lgps,'Color','w','Interpreter','latex')

text(408,3.8,'(a)','FontSize',fontsz+2,'Interpreter','latex')

set(gca,'XTickLabel',{})
yh = ylabel('$M_0$','FontSize',fontsz+2);
set(yh,'Interpreter','latex');
set(gca,'FontName','times','FontSize',fontsz+1)
% title('HR 7001 (Vega, A0Va) magnitude error on spectrum shift','FontWeight','normal','FontSize',fontsz+1,'Interpreter','latex')

text(500,3.5,'HR 7001 (Vega, A0Va), 8.2 nm','FontSize',fontsz+1,'Interpreter','latex')

axes(ha(2));
set(gca,'FontSize',fontsz)

plot(WL,mc(11-1,:),'o-b','MarkerFaceColor',[1 1 1],'LineWidth',1)
hold on
plot(WL,mc(11+1,:),'o-r','MarkerFaceColor',[1 1 1],'LineWidth',1)
plot(WL,mc(11-2,:),'.:b')
plot(WL,mc(11+2,:),'.:r')
hold off


text(408,0.011,'(b)','FontSize',fontsz+2,'Interpreter','latex')
set(gca,'XLim',[400 1050],'YLim',[-0.01 0.015])
set(gca,'YGrid','on')

yh = ylabel('$\delta M_0$','FontSize',fontsz+2);
set(yh,'Interpreter','latex');
xh = xlabel('Wavelength (nm)','FontSize',fontsz+2);
set(xh,'Interpreter','latex');

h = legend('+ 0.5 nm','- 0.5 nm','+ 1 nm','- 1 nm','location','north');
lgps = get(h,'position');
lgps(1) = lgps(1)+0.035;
lgps(2) = lgps(2)+0.16;
set(h,'FontSize',fontsz-1,'position',lgps,'Color','none','Interpreter','latex','orientation','horizontal')

set(gca,'XTick',[400:100:1000])
set(gca,'FontName','times','FontSize',fontsz+1)

outfile2 = strcat('pics/png/','fig09');
outfile5 = strcat('pics/pdf/','fig09');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end
