%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear

set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1); % save pic flag
fontsz = 12;

ma = 1; % air mass
mb = 3; % air mass
mc = 5; % air mass
D1 = 17.8; % telescope diameter (cm)
D2 = 28; % telescope diameter (cm)
h0 = 8000; % altitude scale atmosphere
t = 5*6; % integration time in seconds
p0 = 1013.25; % mbar

load 'data\f12f13\cals.mat' WL
WL = WL*1000;

ch = 1;

Lat0 = 28.3; % Izana
Lon0 = -16.509722; % Izana

tms = datenum([2008 10 01]) + [0:1:340]/(60*24) + 0.5;
[Az, Alt] = RaDec2AzAlt(174.0851,0,tms,Lat0,Lon0);
z = (90-Alt)*pi/180;
airk1 = young1994airmass(z);

dt = 0.5/(24*60);

tms = datenum([2008 10 01]) + [0:1:340]/(60*24) + 0.5;
[Az, Alt] = RaDec2AzAlt(174.0851,0,tms+dt,Lat0,Lon0);
z = (90-Alt)*pi/180;
airk2 = young1994airmass(z);

dm = airk2-airk1;

h = 10;
prs = p0 * exp(-h/h0);
Tm = Tray(prs*1E2,WL(ch)*1E-3);
tau1 = Tm;

h = 2390;
prs = p0 * exp(-h/h0);
Tm = Tray(prs*1E2,WL(ch)*1E-3);
tau2 = Tm;


h = [0:10:5000]; % altitude (m)
prs = p0 * exp(-h/h0);
Tm = Tray(prs*1E2,WL(ch)*1E-3);
tau = Tm;

ps = find(airk1>=2/0.921);
m3 = airk1(ps(1));
dm3 = dm(ps(1));

ps = find(airk1>=4/0.921);
m5 = airk1(ps(1));
dm5 = dm(ps(1));

ps = find(airk1>=6/0.921);
m7 = airk1(ps(1));
dm7 = dm(ps(1));



%%%%%%%%%%%%%%%%%%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(1)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.08 .1],[.3 .03],[.083 .03]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 0.8*5; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));

plot(1.0857*dm3.*tau,h/1000,'-b','LineWidth',1)
hold on
plot(1.0857*dm5.*tau,h/1000,'-r','LineWidth',1)
hold on
plot(1.0857*dm7.*tau,h/1000,'-g','LineWidth',1)
hold off

xlabel('$\delta_{\epsilon}=\delta_{x}\tau$','FontSize',fontsz-1,'Interpreter','latex')
ylabel('Elevation (km)','FontSize',fontsz-1,'Interpreter','latex')

leg1 = legend('$m=2$','$m=4$','$m=6$','location','northeast');
set(leg1,'FontSize',fontsz-1,'Color','w','Interpreter','latex')

set(gca,'YLim',[0 5],'YTick',[0:5],'YTickLabel',{'0','','','','','5'})
grid on
set(gca,'FontName','times','FontSize',fontsz-1)

outfile2 = strcat('pics/png/','fig12');
outfile5 = strcat('pics/pdf/','fig12');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end




figure(2)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.09 .1],[.16 .02],[.125 .015]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 0.8*9.0; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz-2)

plot(airk1,1.0857*dm.*tau1,'-r','LineWidth',1)
hold on
plot(airk1,1.0857*dm.*tau2,'-b','LineWidth',1)
hold off

ylabel('$\delta_{\epsilon}=\delta_{x}\tau$','FontSize',fontsz+1)
set(gca,'XTickLabel',{},'YTick',[0:0.01:0.03],'YTickLabel',num2str([0:0.01:0.03]'))
text(6.5,0.012,'(a)','FontSize',fontsz+1,'Interpreter','latex')

set(gca,'XLim',[1 7],'YLim',[0 0.031])
leg1 = legend('$h$=10 m (Eureka)','$h$=2390 m (Iza\~na)','location','northwest');
set(leg1,'FontSize',fontsz-1,'Color','none','Interpreter','latex')

set(gca,'FontName','times','FontSize',fontsz)

axes(ha(2));
set(gca,'FontSize',fontsz-2)

plot(airk1,dm./airk1.*tau2,'-b','LineWidth',1)
hold on
plot(airk1,dm./airk1.^2.*tau2,'--b','LineWidth',1)
hold off

xlabel('$x$','FontSize',fontsz+1,'Interpreter','latex')
ylabel('$\delta_{\tau}$','FontSize',fontsz+1,'Interpreter','latex')
leg1 = legend('$\delta_{\epsilon}/x$','$\delta_{\epsilon}/x^2$','location','northwest');
set(leg1,'FontSize',fontsz-1,'Color','none','Interpreter','latex')

text(6.5,0.0015,'(b)','FontSize',fontsz+1,'Interpreter','latex')

set(gca,'XLim',[1 7])
set(gca,'FontName','times','FontSize',fontsz)

outfile2 = strcat('pics/png/','fig13');
outfile5 = strcat('pics/pdf/','fig13');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end




