%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);
fontsz = 9;

%%%%%%%%%%%%%%%%%%%%%%%%

load 'data\f15\glwaur.mat' wgl fgl cgl wau fau cau

c = 299792458; % m/s vacuum
c = c/1.0003; % air
h = 6.62607015 * 1e-34; % Js Plank

egl = h*c./(wgl*1e-9); % photon energy J
egl = egl*1e+7; % erg
eau = h*c./(wau*1e-9); % photon energy J
eau = eau*1e+7; % erg


%%%%%%%%%%%%%%%% correct continuum
rg1 = nanmin(fgl)./cgl;
fgl = fgl - nanmin(fgl);
fau = fau - nanmin(fau);

%%%%%%%%%%%%%%%%% flux

fglC = fgl*1E+8*(pi*(36.9/2)^2); % C11 erg s-1 cm-2 cm-1
fglM = fgl*1E+8*(pi*(57.3/2)^2); % M703 erg s-1 cm-2 cm-1

fauC = fau*1E+8*(pi*(36.9/2)^2); % C11 erg s-1 cm-2 cm-1
fauM = fau*1E+8*(pi*(57.3/2)^2); % M703 erg s-1 cm-2 cm-1

cglC = cgl*1E+8*(pi*(36.9/2)^2); % C11 erg s-1 cm-2 cm-1
cglM = cgl*1E+8*(pi*(57.3/2)^2); % M703 erg s-1 cm-2 cm-1

cauC = cau*1E+8*(pi*(36.9/2)^2); % C11 erg s-1 cm-2 cm-1
cauM = cau*1E+8*(pi*(57.3/2)^2); % M703 erg s-1 cm-2 cm-1

% not necessary to multiply by cm^2 size of telescope as it's the same for 
% reference magnitude stars

%%%%%%%%%%%%%%%%%%%%%%%%%%% magnitudes of flux
mfglC = -2.5*log10(fglC+cglC);
mfglM = -2.5*log10(fglM+cglM);

mfauC1 = -2.5*log10(fauC/100+cauC);
mfauM1 = -2.5*log10(fauM/100+cauM);

mfauC2 = -2.5*log10(fauC/10+cauC);
mfauM2 = -2.5*log10(fauM/10+cauM);

%%%%%%%%%%%%%%%%% noise
nfglC = sqrt(fglC.*egl)./egl;
nfglM = sqrt(fglM.*egl)./egl;

nfauC = sqrt(fauC.*eau)./eau;
nfauM = sqrt(fauM.*eau)./eau;

ncauC = sqrt(cauC.*eau)./eau;
ncauM = sqrt(cauM.*eau)./eau;

ncglC = sqrt(cglC.*egl)./egl;
ncglM = sqrt(cglM.*egl)./egl;

%%%%%%%%%%%%%%%%%%%%%%%%%%% magnitudes of noise

mnfglC = -2.5*log10(nfglC);
mnfglM = -2.5*log10(nfglM);

mnfauC1 = -2.5*log10(nfauC/100+ncauC);
mnfauM1 = -2.5*log10(nfauM/100+ncauM);

mnfauC2 = -2.5*log10(nfauC/10+ncauC);
mnfauM2 = -2.5*log10(nfauM/10+ncauM);



load data\f15\liblib.mat stalib wavlib flxlib flx050 flx075 flx100
flx100 = flxlib;
[stahst,ix] = sort(stalib);
flxhst = flx075(ix,:);
% stahst'

%%%%%%%%%%%%%%%%%%%%% A star
f0 = flxhst(6,:)*1E+8;
w0 = wavlib;

m0a = -2.5*log10(f0);

ps = find(~isnan(f0));
fcg = interp1(w0(ps),f0(ps),wgl);
fca = interp1(w0(ps),f0(ps),wau);

psc = find(wgl>530);
psx = find(wau>530);
fc00 = fcg/fcg(psc(1))*10^(-1/2.5); % mag 0
fx00 = fca/fca(psx(1))*10^(-1/2.5); % mag 0

fc01a = fc00 * 10^(-1/2.5); % mag 1
fc02a = fc00 * 10^(-2/2.5); % mag 2
fc03a = fc00 * 10^(-3/2.5); % mag 3

fx01a = fx00 * 10^(-1/2.5); % mag 1
fx02a = fx00 * 10^(-2/2.5); % mag 2
fx03a = fx00 * 10^(-3/2.5); % mag 3


%%%%%%%%%%%%%%%%%%%%% B star
f0 = flxhst(4,:)*1E+8;
w0 = wavlib;


ps = find(~isnan(f0));
fcg = interp1(w0(ps),f0(ps),wgl);
fca = interp1(w0(ps),f0(ps),wau);

psc = find(wgl>530);
psx = find(wau>530);
fc00 = fcg/fcg(psc(1))*10^(-1/2.5); % mag 0
fx00 = fca/fca(psx(1))*10^(-1/2.5); % mag 0

fc01b = fc00 * 10^(-1/2.5); % mag 1
fc02b = fc00 * 10^(-2/2.5); % mag 2
fc03b = fc00 * 10^(-3/2.5); % mag 3

fx01b = fx00 * 10^(-1/2.5); % mag 1
fx02b = fx00 * 10^(-2/2.5); % mag 2
fx03b = fx00 * 10^(-3/2.5); % mag 3

%%% attenuation
prs0 = 1013.25E2; % Pa
trau = Tray(prs0,wau*1e-3);
trag = Tray(prs0,wgl*1e-3);
rrau = exp(-trau);
rrag = exp(-trag);

%%%%%%%%%%%%%%%%%%%%%%%%%
% kR/A normalised to 250 R at 5577 A
load 'data\f15\airglowRA.mat' wg fg75 cng
rg0 = nanmin(fg75)./cng;
fg75 = fg75 - nanmin(fg75);

% kR/A normalised to 100 kR (IBC 3)
load 'data\f15\auroraRA.mat' wr fr fr75 cr
fr75 = fr75 - nanmin(fr75);




figure(3)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.015 .2],[.145 .025],[.135 .025]);


set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 9; height = 2.*3.2; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));
set(gca,'FontSize',fontsz)

semilogy(wg,(fg75+cng.*rg0)*1e+3,'k') % no continuum change
hold on
semilogy(wr,(fr75/100+cr)*1e+3,'b')
semilogy(wr,(fr75/10+cr)*1e+3,'r')
semilogy(wr,(fr75+cr)*1e+3,'g')
hold off

ylabel('Emission (R/\AA)','Interpreter','latex')
set(gca,'XTickLabel',{})
text(1050,3,'a)','FontSize',fontsz+1)
grid on

hh = legend('airglow','aurora IBC1','aurora IBC2','aurora IBC3','location','North');
set(hh,'FontSize',fontsz-3,'Interpreter','latex','orientation','horizontal')
hh.ItemTokenSize = [30,18]/2; % default x1=30 and x2=18

lgps = get(hh,'position');
lgps(1) = lgps(1)+0.02;
lgps(2) = lgps(2)+0.04;
set(hh,'position',lgps)

ps = find(~isnan(fx03a));
set(gca,'XLim',[300 wau(ps(end))],'YLim',[1 1e+4])
set(gca,'FontName','times','FontSize',fontsz)


axes(ha(2));
set(gca,'FontSize',fontsz)

semilogy(wgl,(fglC+cglC.*rg1)./(fc03a.*rrag),'k')
hold on


semilogy(wau,(fauC/100+cauC)./(fx03a.*rrau),'b')
semilogy(wau,(fauC/10+cauC)./(fx03a.*rrau),'r')
semilogy(wau,(fauM/10+cauM)./(fx03a.*rrau),':r')
semilogy(wau,(fauC/1+cauC)./(fx03a.*rrau),'g')

ps = find(~isnan(fx03a));
hold off
grid on

hh = legend('airglow','IBC1','IBC2','IBC2 @M703','IBC3','location','North');
set(hh,'FontSize',fontsz-3,'Interpreter','latex','orientation','horizontal')
hh.ItemTokenSize = [30,18]/2; % default x1=30 and x2=18

lgps = get(hh,'position');
lgps(1) = lgps(1)+0.02;
lgps(2) = lgps(2)+0.04;
set(hh,'position',lgps)

ylabel('$\delta_F/F$','Interpreter','latex')
xlabel('Wavelength (nm)','Interpreter','latex')
text(1050,0.4*1e-4,'b)','FontSize',fontsz+1)

set(gca,'XLim',[300 wau(ps(end))],'YLim',[1e-5 0.5])
set(gca,'FontName','times','FontSize',fontsz)


outfile2 = strcat('pics/png/fig15');
outfile5 = strcat('pics/pdf/fig15');

if flg
    print('-dpng', '-r300', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end

