%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear

set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);
fontsz = 9;
ft = 17;
meth = 'spline';

load 'data\f16\dome.mat' wav bgd rms
dome = bgd';

load 'data\f16\bgd18031005.mat' 
% wav bg2943 bg5191 CB x2943 x5191 t2943 t5191

load 'data\f16\bgds.mat'
% wav bg0015 bg7001 x0015 x7001 t0015 t7001

load 'data\f16\multiPKV.mat' 
% wav Cp Tp Tm ---------- Best Pukovo

load 'data\f16\skys.mat' 
% wsky tsky msky fsky dome tsky0 msky0 fsky0

F2a = bg7001-dome;
F2 = fsky0;
S2 = -2.5*log10(F2);

C = Cp;
c = 10.^(-C/2.5);
I2 = F2.*c;
I2a = F2a.*c;
M2 = -2.5*log10(I2/(pi*(36.9/2)^2));
M2a = -2.5*log10(I2a/(pi*(36.9/2)^2));


load 'data\f16\vegaflx.mat' veg S prs mas
xas = mas./0.921;
Tm = Tray(prs,wav/1000);
veg0 = veg.*exp(mas*Tm);
dF0 = F2./veg0;
v0 = veg0.*c;


% get HST Vega spectrum in mags
load data\f16\liblib.mat stalib wavlib flxlib flx050 flx075 flx100
flx100 = flxlib;
[stahst,ix] = sort(stalib);
flxhst = flx100(ix,:)/1E-7;
% wavhst = wavlib;
flxhst = flxhst([1,3:end],:); % remove sspstd (not space)
stahst = stahst([1,3:end]);
veghst = flxhst(5,:);

% corret satellite wavelenths
load 'data\f16\wavsat.mat' csat wsat
wavhst = wsat;




figure(5)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.03 .2],[.175 .03],[.12 .04]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 10; height = 5.5; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz)


plot(wav,M2,'k')
hold on
plot(wav,M2a,'m')
hold off

set(gca,'XLim',[400 1100],'YLim',[15 22])
set(gca,'YTick',[15:22],'YTickLabel',{'','16','','18','','20','','22'})

hh = legend(datestr(tsky0,'yyyy-mm-dd HH:MM'),datestr(t7001,'yyyy-mm-dd HH:MM'),'location','south','orientation','horizontal');
hh.ItemTokenSize = [30,18]/3; % default x1=30 and x2=18
set(hh,'FontSize',fontsz-1,'Interpreter','latex')

lgps = get(hh,'position');
lgps(1) = lgps(1)-0.00;
lgps(2) = lgps(2)-0.05;
set(hh,'position',lgps)
text(415,21.3,'a)','FontSize',fontsz)

daty = ylabel('mag/arcsec$^2$','Interpreter','latex');
set(gca,'FontName','times','FontSize',fontsz+1)
set(gca,'XTicklabel',{})

grid on



axes(ha(2));
set(gca,'FontSize',fontsz)

semilogy(wav,dF0/10^(-0/2.5),'b') % I and catalog in erg
hold on
semilogy(wav,dF0/10^(-3/2.5),'r')
hold off
set(gca,'XLim',[400 1100],'Ylim',[1e-5 1])
set(gca,'YTick',[0.0001 0.01 1])

xlabel('Wavelength (nm)','Interpreter','latex')
ylabel('$B/F$','Interpreter','latex')
grid on
text(415,2.5*1e-1,'b)','FontSize',fontsz)

hh = legend('V=0','V=3','location','north','orientation','horizontal');
hh.ItemTokenSize = [30,18]/3; % default x1=30 and x2=18
set(hh,'FontSize',fontsz-1,'Interpreter','latex')

lgps = get(hh,'position');
lgps(1) = lgps(1)-0.00;
lgps(2) = lgps(2)+0.05;
set(hh,'position',lgps)

set(gca,'FontName','times','FontSize',fontsz)

outfile2 = strcat('pics/png/fig16');
outfile5 = strcat('pics/pdf/fig16');

if flg
    print('-dpng', '-r300', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end