%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1); % save pic flag
fontsz = 8;

fwsig = 2*sqrt(2*log(2));
fov = 36.9; % eureka
% fov = 57.3; % sherbrooke

load 'data\f18\gssgs3.mat'
% sigv, fsm0, sigm2, sigm3, sigm4, sigm6

load 'data\f18\sbigeu.mat' 
% tmsx masx fwx fwxm fwxr expx snbx snmx sng masm fwm sngm nx sng0 pwr0 sngm0 pwrm0 dif
%%%%%%%%%%%%%%%%%%%%%%%%%%%
p = polyfit(log10(masm),log10(fwm),1);
pwrfm = p(1);
fwfm = 10^p(2);
fwmeu = fwfm * nx.^pwrfm;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for i=1:length(nx)
    sig = 0.92*fwmeu(i)/fwsig;
    prcm0(i) = interp1(sigv,fsm0,sig); % calib
    sigj = 0.3*fwmeu(i);
    sg2 = interp1(sigv,sigm2,sigj); % 2" centring rms
    sg3 = interp1(sigv,sigm3,sigj); % 2" centring rms
    sg4 = interp1(sigv,sigm4,sigj); % 4" centring rms
    sg6 = interp1(sigv,sigm6,sigj); % 6" centring rms
    prcm2(i) = interp1(sigv,fsm0,sqrt(sig^2+sg2^2)); % calib + 2" centring rms
    prcm3(i) = interp1(sigv,fsm0,sqrt(sig^2+sg3^2)); % calib + 3" centring rms
    prcm4(i) = interp1(sigv,fsm0,sqrt(sig^2+sg4^2)); % calib + 4" centring rms
    prcm6(i) = interp1(sigv,fsm0,sqrt(sig^2+sg6^2)); % calib + 6" centring rms
    
    sig = 1*fwmeu(i)/fwsig;
    sigj = 0.3*fwmeu(i);
    sg4 = interp1(sigv,sigm4,sigj); % 4" centring rms
    prcm4b(i) = interp1(sigv,fsm0,sqrt(sig^2+sg4^2)); % calib + 4" centring rms
end

dC = -2.5*log10(prcm0);
dM2 = -2.5*log10(prcm2);
dM3 = -2.5*log10(prcm3);
dM4 = -2.5*log10(prcm4);
dM4b = -2.5*log10(prcm4b);
dM6 = -2.5*log10(prcm6);



figure(1)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.12 .1],[.2 .095],[.15 .01]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 8.3; height = 4; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));

loglog(nx/0.921, dC,'-k','LineWidth',1)
hold on
loglog(nx/0.921, dM2,'-b','LineWidth',0.5)
loglog(nx/0.921, dM3,'-m','LineWidth',0.5)
loglog(nx/0.921, dM4,'-r','LineWidth',0.5)
loglog(nx/0.921, dM4b*nan,'--r','LineWidth',0.5)
loglog(nx/0.921, dM6,'-g','LineWidth',0.5)
loglog(nx/0.921, dM4b,'--r','LineWidth',0.5)
hold off

set(gca,'XLim',[1 13.5],'YLim',[0.001 0.2])
lg1 = legend('$\delta_c=0^{\prime\prime}$','$\delta_c=2^{\prime\prime}$',...
    '$\delta_c=3^{\prime\prime}$','$\delta_c=4^{\prime\prime}$',...
    '$\delta_c=4^{\prime\prime}$, 1.08$\omega$','$\delta_c=6^{\prime\prime}$','location','NorthWest');
lgps = get(lg1,'position');
lgps(1) = lgps(1)-0.09;
lgps(2) = lgps(2)+0.245;
set(lg1,'FontSize',fontsz-1,'color','w','position',lgps,'Interpreter','latex')

ylabel('$\delta_{\epsilon}$ @ 640 nm','FontSize',fontsz,'Interpreter','latex')
xlabel('$x$','FontSize',fontsz,'Interpreter','latex')
set(gca,'FontName','times','FontSize',fontsz)
title('Flux loss beyond FOV {\it vs} centring error $\delta_c$','FontSize',fontsz,'FontWeight','normal','Interpreter','latex')

set(gca,'XTick',[1,2,3:2:13])
set(gca,'YTick',[0.001 0.01 0.1])
set(gca,'YTickLabel',num2str([0.001 0.01 0.1]'))

grid on

outfile1 = strcat('pics/png/','fig18');
outfile4 = strcat('pics/pdf/','fig18');

if flg
    print('-dpng', '-r400', [outfile1,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile4,'.pdf'])
end
