%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1); % save pic flag
fontsz = 9;

load 'data/f19/osm.mat' tms1S m1S nbs1S tem1S CN1S SC1S HC1S
load 'data/f19/osmtau.mat' tms1S nbs1S sname1S m1S tem1S SC1S HC1S Tau1S WL

tms0 = tms1S-fix(tms1S(1));
ps = find(tms0>384.4 & tms0<384.52);

h1 = HC1S(1,ps);

t0 = fix(tms0(ps(1)))+10.5/24;

pxi = find((tms0(ps)-fix(tms0(ps(1))))*24-5>5.5 & (tms0(ps)-fix(tms0(ps(1))))*24-5<6);
pss = ps(pxi);
H1 = HC1S(1,pss);
M1 = -2.5*log10(H1)+8.9;
t1 = (tms0(pss)-fix(tms0(ps(1))))*24-5;
t1x = (tms0(ps)-fix(tms0(ps(1))))*24-5;
p = polyfit(t1,M1,1);
Mf1 = t1x.*p(1)+p(2);
nH1 = 10.^(-(Mf1-8.9)./2.5);

tx = [(t0-fix(tms0(ps(1))))*24-5 t1x];
M1 = -2.5*log10(h1)+8.9;
M1x = interp1(t1x,M1,tx,'linear','extrap');
Mf1x = interp1(t1x,Mf1,tx,'linear','extrap');
S1 = -2.5*log10(CN1S(ps,1))'+8.9;
S1x = interp1(t1x,S1,tx,'linear','extrap');

figure(10)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.15 .1],[.25 .01],[.11 .01]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 8.3; height = 3.6; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));

plot(tx,M1x,'-b','LineWidth',1)
hold on
plot(tx,S1x,'-r','LineWidth',1)
hold on
plot(tx,-2.5*log10(repmat(max(CN1S(ps,1)),1,length(ps)+1))'+8.9,'--k','LineWidth',0.25)
hold off

yAX = get(gca,'YAxis');
set(yAX,'FontSize', fontsz-1)
ylabel('$M$ (Vega)','FontSize',fontsz,'Interpreter','latex')

xAX = get(gca,'XAxis');
set(xAX,'FontSize', fontsz-1)
leg1 = legend('sky background','sky-substracted $M$','expected $M$','location','northwest');
set(gca,'YLim',[-2 5],'XLim',[10.5 11.72]-5)

xv = 5+[30 45 60 60+15 60+30]/60;
set(gca,'XTick',xv)
set(gca,'XTickLabel',datestr(xv/24,'hh:MM'))
xlabel(['Local time (HH:MM) (', datestr(tms1S(ps(1)),'dd-mmm-yyyy'),', Eureka)'],'FontSize',fontsz)

set(leg1,'FontSize',fontsz-2,'Color','w','Interpreter','latex')
lgps = get(leg1,'position');
lgps(1) = lgps(1)-0.025;
lgps(2) = lgps(2)+0.07;
set(leg1,'position',lgps)

text(5.55,-1,'@400 nm','FontSize',fontsz,'Interpreter','latex')
set(gca,'FontName','times','FontSize',fontsz)

outfile2 = strcat('pics/png/','fig19');
outfile5 = strcat('pics/pdf/','fig19');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end
