%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);

fontsz = 12;

% read high resolution daylight sky) %%%%%%%%%%%%%%%%%
pat = 'data\f20\';
files = dir([pat,'ASTMG173.csv']);

fid = fopen([pat, files(1).name],'r');
data = textscan(fid,'%s%s%s%s %*[^\n]','headerLines',2,'delimiter',',');
fclose(fid);

ws0 = str2double(strrep(data{1},',','.'));
fs0 = str2double(strrep(data{2},',','.'));
fs1 = str2double(strrep(data{3},',','.'));
fs2 = str2double(strrep(data{4},',','.'));
fss = fs1-fs2;

% read high resolution daylight sky) %%%%%%%%%%%%%%%%%
pat = 'data\f20\';
files = dir([pat,'ST1-180218153302-sky.chg']);

fid = fopen([pat, files(1).name],'r');
data = textscan(fid,'%s%s %*[^\n]','headerLines',7);
fclose(fid);

wav = str2double(strrep(data{1},',','.'));
flx = str2double(strrep(data{2},',','.'));

fname = files(1).name;
tmpnm = fname(5:16);
yr = 2000 + str2double(tmpnm(1:2));
mo = str2double(tmpnm(3:4));
dy = str2double(tmpnm(5:6));
hr = str2double(tmpnm(7:8));
mn = str2double(tmpnm(9:10));
sc = str2double(tmpnm(11:12));
tms = datenum([yr mo dy hr mn sc]);

bgd = ones(size(flx))*(flx(end)-0.1);

mag = -2.5*log10((flx-bgd)*1.6);
load 'data\f20\calmgfit.mat' wav Cm
magS = mag+Cm';
flxS = 10.^(-(magS)/2.5); % erg/s/cm2/cm (10 x W/m2/m)


%%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.08 .1],[.21 .04],[.105 .035]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 0.9*6; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz)

plot(ws0,fss,'b')
hold on
plot(wav,flxS,'r','LineWidth',1)
hold off
set(gca,'xLim',[400 1100])

xAX = get(gca,'XAxis');
set(xAX,'FontSize', fontsz-1)
xlabel('Wavelength (nm)','Fontsize',fontsz,'Interpreter','latex')
yAX = get(gca,'YAxis');
set(yAX,'FontSize', fontsz-1)
ylabel('Irradiance (Wm$^{-2}$nm$^{-1}$)','Fontsize',fontsz,'Interpreter','latex')
leg1 = legend('indirect solar spectrum reference','scaled STP daylight background','location','northeast');
set(leg1,'FontSize',fontsz-2,'Color','w','Interpreter','latex')

set(gca,'FontName','times')

outfile2 = strcat('./pics/png/','fig20');
outfile5 = strcat('./pics/pdf/','fig20');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end
