%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);

fontsz = 12;

load 'data/f21/osm.mat' 
% WL1S tms1S m1S nbs1S tem1S CN1S SNR1S SEMI1S SC1S SV1S SN1S HC1S HV1S HN1S

ps = find((tms1S-fix(tms1S(1))) > 670/60/24 & (tms1S-fix(tms1S(1))) < 870/60/24);
tms = tms1S(ps);
nbs1S = nbs1S(ps);
SC = SC1S(:,ps);
SV = SV1S(:,ps);
HC = HC1S(:,ps);
HV = HV1S(:,ps);
CN = CN1S(:,ps);
WL = WL1S(:,ps);

cmap = hsv(270);
cmap = flipud(cmap(1:256-30,:));
ix = [3,7,11,12,13,16,17];
wav = WL(:,1);
dwr = 1050-400;
dwi = wav-400;
iw = round(dwi./dwr*(255-30))+1;

HCx = HC(ix,:);
Hi = HCx-409;
ti = (tms-fix(tms(1)))*24-5;


%%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

figure(1)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.08 .1],[.22 .02],[.11 .13]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 1.5*8.3; height = 0.9*6; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz-2)

sz = size(HCx);
for i=1:sz(1)
    semilogy(ti,Hi(i,:),'-','color',cmap(iw(ix(i)),:))
    hold on
end
hold off
set(gca,'YLim',[0.1 4000],'XLim',[670 870]/60-5,'YTick',[1, 10, 100, 1000])
colormap(cmap)
set(gca,'CLim',[400 1065]/1000)

xv = get(gca,'XTick');
set(gca,'XTickLabel',datestr(xv/24,'hh:MM'))

ax = get(gca,'Position');
hc=colorbar;
p = get(hc,'Position');
p(1) = ax(1)+ax(3)+0.02;
p(2) = ax(2);
p(3) = p(3)/3;
set(hc,'Position',p);
ylabel(hc,'wavelength ($\mu$m)','FontSize', fontsz,'Interpreter','latex');
set(hc,'FontSize', fontsz-2)
hc.Ticks = [0.4 0.6 0.8 1.0];
hc.TickLabels = num2str([0.4 0.6 0.8 1.0]','%2.1f');

xAX = get(gca,'XAxis');
set(xAX,'FontSize', fontsz-1)
xlabel(['Local time (HH:MM) (',datestr(tms(1)-5/24,'dd-mmm-yyyy'),', Eureka)'],...
    'Fontsize',fontsz,'Interpreter','latex')
yAX = get(gca,'YAxis');
set(yAX,'FontSize', fontsz-1)
ylabel('Background (cnt/s)','Fontsize',fontsz,'Interpreter','latex')
set(gca,'FontName','times')
grid on

outfile2 = strcat('./pics/png/','fig21');
outfile5 = strcat('./pics/pdf/','fig21');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end

