%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);

fontsz = 10;

load 'data\f23\vartms.mat' WL tms star airm tem ITB A SN HN SC SV HC HV CN SNR SEMI

for ft = 1:17

    ps = find(tem>41.5);
    psup = find(tem>32.5);
    tvec = tem(ps);
    bgd = squeeze(HC(ft,:,:));
    bvec = bgd(ps)-min(min(bgd(psup)));
    
    p = polyfit(tvec,bvec,1);
    fit1 = p(1)*(tvec)+p(2);
    
    rms = std(bvec-fit1);
    
    ps = find(abs(bvec-fit1)<rms);
    p = polyfit(tvec(ps),bvec(ps),1);
    fit2 = p(1)*(tvec)+p(2);
    
    tem0 = -p(2)/p(1);
    tem0v(ft) = tem0;
    
    rms = std(bvec-fit2);
    
    ps2 = find(abs(bvec-fit2)<rms);
    p = polyfit(tvec(ps2)-tem0,bvec(ps2),1);
    fit3 = p(1)*(tvec-tem0)+p(2);
    
    pf1(ft) = p(1);
    pf2(ft) = p(2);
    
    slope(ft) = mean(bvec(ps2)./(tvec(ps2)-tem0));
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


dt(1,:) = std(tem(1:2,:),1);
dt(2,:) = std(tem,1)/2;
dt(3,:) = std(tem(2:3,:),1);

tmsv = reshape(tms,3*length(squeeze(tms(1,:))),1);
temv = reshape(tem,3*length(squeeze(tem(1,:))),1);
starv = reshape(star,3*length(squeeze(star(1,:))),1);
dtv = reshape(dt,3*length(squeeze(tem(1,:))),1);
airmv = reshape(airm,3*length(squeeze(tem(1,:))),1);
CN05v = reshape(squeeze(CN(5,:,:)),3*length(squeeze(tms(1,:))),1);
CN17v = reshape(squeeze(CN(17,:,:)),3*length(squeeze(tms(1,:))),1);
HC05v = reshape(squeeze(HC(5,:,:)),3*length(squeeze(tms(1,:))),1);
HC17v = reshape(squeeze(HC(17,:,:)),3*length(squeeze(tms(1,:))),1);

[tmsv,idx] = sort(tmsv);
temv = temv(idx);
starv = starv(idx);
dtv = dtv(idx);
airmv = airmv(idx);
CN05v = CN05v(idx);
CN17v = CN17v(idx);
HC05v = HC05v(idx);
HC17v = HC17v(idx);

err05v = slope(5)*dtv./(CN05v.*airmv*4); % /4 = 30''/2'
err17v = slope(17)*dtv./(CN17v.*airmv*4);

psv = find(temv<41.5);

temv0 = temv;
dtv0 = dtv;
airmv0 = airmv;
CN05v0 = CN05v;
CN17v0 = CN17v;
err05v0 = err05v;
err17v0 = err17v;

temv0(psv) = nan;
dtv0(psv) = nan;
airmv0(psv) = nan;
CN05v0(psv) = nan;
CN17v0(psv) = nan;
err05v0(psv) = nan;
err17v0(psv) = nan;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plot ft 5
ft = 5;
pshi = find(temv>41.5);
psup = find(temv>32.5);
tvec = temv(pshi);

%%%%%%%%%
bgd = HC05v;
bvec = bgd(pshi)-min(min(bgd(psup)));

p = polyfit(tvec,bvec,1);
fit1 = p(1)*(tvec)+p(2);

rms = std(bvec-fit1);

ps = find(abs(bvec-fit1)<rms);
p = polyfit(tvec(ps),bvec(ps),1);
fit2 = p(1)*(tvec)+p(2);

tem0 = -p(2)/p(1);

rms = std(bvec-fit2);

ps2 = find(abs(bvec-fit2)<rms);
p = polyfit(tvec(ps2)-tem0,bvec(ps2),1);
fit05 = p(1)*(tvec-tem0)+p(2)+min(min(bgd(psup)));

%%%%%%%%%
bgd = HC17v;
bvec = bgd(pshi)-min(min(bgd(psup)));

p = polyfit(tvec,bvec,1);
fit1 = p(1)*(tvec)+p(2);

rms = std(bvec-fit1);

ps = find(abs(bvec-fit1)<rms);
p = polyfit(tvec(ps),bvec(ps),1);
fit2 = p(1)*(tvec)+p(2);

tem0 = -p(2)/p(1);

rms = std(bvec-fit2);

ps2 = find(abs(bvec-fit2)<rms);
p = polyfit(tvec(ps2)-tem0,bvec(ps2),1);
fit17a = p(1)*(tvec-tem0)+p(2)+min(min(bgd(psup)));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bgd = HC17v;
bvec = bgd(pshi);

p = polyfit(tvec,log10(bvec),1);
fit1 = p(1)*([42:53])+p(2);

fit17 = 10.^fit1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


figure(10)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(1,1,[.15 .1],[.23 .02],[.15 .02]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 9; height = 4.4; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));
set(gca,'FontSize',fontsz-1)


semilogy(temv,HC17v,'ob','MarkerSize',3);
hold on
semilogy(temv(pshi),HC17v(pshi),'or','MarkerSize',3);
hold on
semilogy([42:53],fit17,'k-','linewidth',1);
hold off

set(gca,'XLim',[40 53],'YLim',[350 410])
xlabel('Temperature ($^\circ$C)','Interpreter','latex')
ylabel('$B$ (cnt/s)','Interpreter','latex')
leg1 = legend('$< 41.5$ $^\circ$C','$> 41.5$ $^\circ$C','exponential fit','Location','southeast');
set(leg1,'FontSize',fontsz-1,'Color','none','Interpreter','latex')

set(gca,'FontName','times','FontSize',fontsz)

outfile2 = strcat('pics/png/','fig23');
outfile5 = strcat('pics/pdf/','fig23');

if flg
    print('-dpng', '-r400', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end


