%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear
set(0,'DefaultTextInterpreter', 'latex')

flg = logical(1);
fontsz = 9;
ft = 17;

% WL - wavelength in nm

% SN  Star elemantary measurements
% HN  Background elemantary measurements
% SC - Measuring signal Star in Counts/s., arithmetic mean average value of the SN
% SV - coefficient of variance SC
% HC - Measuring signal Background in Counts/s., arithmetic mean average value of the HN
% HV - coefficient of variance HC
% CN = SC - HC
% SNR = 10 * lg(SC/HC)

% PREPARE DATA %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load 'data\f24\vartms2S.mat' WL tms star airm tem ITB A SN HN SC SV HC HV CN SNR SEMI

% low star %%%%%%%%%%%%%%%%%%%%%%%%%
tms_lo = [tms(1,:) tms(3,:)];
star_lo = [star(1,:) star(3,:)];
airm_lo = [airm(1,:) airm(3,:)];
tem_lo = [tem(1,:) tem(3,:)];
ITB_lo = [ITB(1,:) ITB(3,:)];
A_lo = [A(1,:) A(3,:)];
SN_lo = [SN(1,:), SN(3,:)];
HN_lo = [HN(1,:), HN(3,:)];

SC_lo = [squeeze(SC(:,1,:)), squeeze(SC(:,3,:))];
SV_lo = [squeeze(SV(:,1,:)), squeeze(SV(:,3,:))];
HC_lo = [squeeze(HC(:,1,:)), squeeze(HC(:,3,:))];
HV_lo = [squeeze(HV(:,1,:)), squeeze(HV(:,3,:))];
CN_lo = [squeeze(CN(:,1,:)), squeeze(CN(:,3,:))];
SNR_lo = [squeeze(SNR(:,1,:)), squeeze(SNR(:,3,:))];
SEMI_lo = [squeeze(SEMI(:,1,:)), squeeze(SEMI(:,3,:))];

[tms_lo, idx] = unique(tms_lo);
star_lo = star_lo(idx);
airm_lo = airm_lo(idx);
tem_lo = tem_lo(idx);
ITB_lo = ITB_lo(idx);
A_lo = A_lo(idx);
SN_lo = SN_lo(idx);
HN_lo = HN_lo(idx);

SC_lo = SC_lo(:,idx);
SV_lo = SV_lo(:,idx);
HC_lo = HC_lo(:,idx);
HV_lo = HV_lo(:,idx);
CN_lo = CN_lo(:,idx);
SNR_lo = SNR_lo(:,idx);
SEMI_lo = SEMI_lo(:,idx);

% hi star %%%%%%%%%%%%%%%%%%%%%%%%%
tms_hi = tms(2,:);
star_hi = star(2,:);
airm_hi = airm(2,:);
tem_hi = tem(2,:);
ITB_hi = ITB(2,:);
A_hi = A(2,:);
SN_hi = SN(2,:);
HN_hi = HN(2,:);

SC_hi = squeeze(SC(:,2,:));
SV_hi = squeeze(SV(:,2,:));
HC_hi = squeeze(HC(:,2,:));
HV_hi = squeeze(HV(:,2,:));
CN_hi = squeeze(CN(:,2,:));
SNR_hi = squeeze(SNR(:,2,:));
SEMI_hi = squeeze(SEMI(:,2,:));

% correct background on hi star %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tmsz = tms_hi;
temz = tem_hi;
airmz = airm_hi;
HCz = HC_hi;
SCz = SC_hi;

CNz = SCz-HCz;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tmsdy = datenum([2011 02 24]);
ps1 = find( tmsz>(tmsdy+9.2/24) & tmsz<(tmsdy+11.5/24+0.1/24) );
tmsdy = datenum([2012 02 28]);
ps2 = find( tmsz>(tmsdy-1/24) & tmsz<(tmsdy+1.5/24+0.1/24) );
tmsdy = datenum([2012 03 06]);
ps3 = find( tmsz>(tmsdy+0/24) & tmsz<(tmsdy+(2.22+0.1)/24+0.1/24) );

tmsz1 = tmsz(ps1);
temz1 = temz(ps1);
m1 = airmz(ps1);
HCz1 = HCz(:,ps1);
SCz1 = SCz(:,ps1);
CNz1 = CNz(:,ps1);
M1 = -2.5*log10(CNz1);

tmsz2 = tmsz(ps2);
temz2 = temz(ps2);
m2 = airmz(ps2);
HCz2 = HCz(:,ps2);
SCz2 = SCz(:,ps2);
CNz2 = SCz2-HCz2;
M2 = -2.5*log10(CNz2);

CNb2 = SCz2 - repmat(HCz2(:,end),1,length(ps2));
dCN2 = CNz2 - repmat(CNz2(:,end),1,length(ps2));
S2 = -2.5*log10(abs(CNb2));
dS2 = abs(S2-repmat(S2(:,end),1,length(ps2)));

dS2r = abs(CNb2-repmat(CNb2(:,end),1,length(ps2)))./CNb2;

Sz2 = -2.5*log10(abs(CNz2));
dSz2 = abs(Sz2-repmat(Sz2(:,end),1,length(ps2)));
dCNz2 = 10.^(-dSz2/2.5);

rCN2 = CNz2./repmat(CNz2(:,end),1,length(ps2));

bCN2 = CNb2./repmat(CNb2(:,end),1,length(ps2));
dHC2 = HCz2 - repmat(HCz2(:,end),1,length(ps2));

tmsz3 = tmsz(ps3);
temz3 = temz(ps3);
m3 = airmz(ps3);
HCz3 = HCz(:,ps3);
SCz3 = SCz(:,ps3);
CNz3 = CNz(:,ps3);
M3 = -2.5*log10(CNz3);

CNb3 = SCz3 - repmat(HCz3(:,end),1,length(ps3));
S3 = -2.5*log10(abs(CNb3));
dS3 = abs(S3-repmat(S3(:,end-1),1,length(ps3)));

cmap = hsv(270);
cmap = flipud(cmap(1:256-30,:));
ix = [3,7,11,12,13,16,17];
wav = WL*1000;
dwr = 1050-400;
dwi = wav-400;
iw = round(dwi./dwr*(255-30))+1;


figure(3)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(3,1,[.015 .2],[.14 .01],[.12 .15]);


set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 9; height = 2.*3.5; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);


axes(ha(1));
set(gca,'FontSize',fontsz)

for i=1:length(ix)
    plot(temz2,(dHC2(ix(i),:)),'-','color',cmap(iw(ix(i)),:),'Markersize',3)
    hold on
end
hold off
colormap(cmap)
set(gca,'CLim',[400 1050]/1000)

ax = get(gca,'Position');
hc=colorbar;
p = get(hc,'Position');
p(1) = ax(1)+ax(3)+0.02;
p(2) = ax(2);
p(3) = p(3)/4;
set(hc,'Position',p);
ylabel(hc,'wavelength','FontSize', fontsz-1,'Interpreter','latex');
hc.Ticks = [0.4 0.6 0.8 1.0];
hc.TickLabels = num2str([0.4 0.6 0.8 1.0]','%2.1f');

ylabel('$\delta_B$ (cnt/s)','Interpreter','latex')
set(gca,'XTickLabel',{})

text(29.5,-4,'a)','FontSize',fontsz+1)
text(8,0,[datestr(tmsz2(1),'yyyy/mm/dd, HH:MM--'),datestr(tmsz2(end),'HH:MM')],'FontSize',fontsz,'Interpreter','latex')

set(gca,'YLim',[-5.5 1],'XLim',[7.1 31.5])
set(gca,'FontName','times','FontSize',fontsz)


axes(ha(2));
set(gca,'FontSize',fontsz)

for i=1:length(ix)
    plot(temz2,(bCN2(ix(i),:)),'-','color',cmap(iw(ix(i)),:),'Markersize',3)
    hold on
end
hold off
colormap(cmap)
set(gca,'CLim',[400 1050]/1000)

ax = get(gca,'Position');
hc=colorbar;
p = get(hc,'Position');
p(1) = ax(1)+ax(3)+0.02;
p(2) = ax(2);
p(3) = p(3)/4;
set(hc,'Position',p);
ylabel(hc,'wavelength','FontSize', fontsz-1,'Interpreter','latex');
set(hc,'FontSize', fontsz-1)
hc.Ticks = [0.4 0.6 0.8 1.0];
hc.TickLabels = num2str([0.4 0.6 0.8 1.0]','%2.1f');


ylabel('$F/F_e$','Interpreter','latex')
set(gca,'XTickLabel',{})

text(29.5,0.66,'b)','FontSize',fontsz+1)

set(gca,'YLim',[0.25 1.05],'XLim',[7.1 31.5])
set(gca,'FontName','times','FontSize',fontsz)


axes(ha(3));
set(gca,'FontSize',fontsz)

for i=1:length(ix)
    plot(temz2,(dS2r(ix(i),:))./m2,'-','color',cmap(iw(ix(i)),:),'Markersize',3)
    hold on
end
hold off
colormap(cmap)
set(gca,'CLim',[400 1050]/1000)

ax = get(gca,'Position');
hc=colorbar;
p = get(hc,'Position');
p(1) = ax(1)+ax(3)+0.02;
p(2) = ax(2);
p(3) = p(3)/4;
set(hc,'Position',p);
ylabel(hc,'wavelength','FontSize', fontsz-1,'Interpreter','latex');
set(hc,'FontSize', fontsz-1)
hc.Ticks = [0.4 0.6 0.8 1.0];
hc.TickLabels = num2str([0.4 0.6 0.8 1.0]','%2.1f');
th = title(hc,'$\mu$m','FontSize', fontsz-1,'Interpreter','latex');
pos = th.Position;
th.Position = [pos(1) -pos(2)/5 0]; % to change its position

text(29.5,0.25,'c)','FontSize',fontsz+1)

ylabel('$\delta_{\epsilon}$','Interpreter','latex')
xlabel('Temperature ($^\circ$C)','Interpreter','latex')

set(gca,'YLim',[0 2.2],'XLim',[7.1 31.5])
set(gca,'FontName','times','FontSize',fontsz)


outfile2 = strcat('pics/png/fig24');
outfile5 = strcat('pics/pdf/fig24');

if flg
    print('-dpng', '-r300', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end