%  Liviu Ivanescu (gruiva@gmail.com), Universit de Sherbrooke, 23.03.2021
clear

set(0,'DefaultTextInterpreter', 'latex')

colororder = [
	0.00  0.00  1.00
	0.00  0.50  0.00
	1.00  0.00  0.00
	0.00  0.75  0.75
	0.75  0.00  0.75
	0.75  0.75  0.00
	0.25  0.25  0.25
	0.75  0.25  0.25
	0.95  0.95  0.00
    0.75  0.75  0.75
	0.25  0.25  0.75
	0.00  1.00  0.00
	0.76  0.57  0.17
	0.54  0.63  0.22
	0.34  0.57  0.92
	1.00  0.10  0.60
	0.88  0.75  0.73
	0.10  0.49  0.47
	0.66  0.34  0.65
	0.99  0.41  0.23
];


flg = logical(1);
fontsz = 11;
ft = 17;
meth = 'spline';

% Eureka 7959:27 N 8556:20 W (140 m)
lat0 = 79 + 59/60 + 27/3600;
lon0 = -(85 + 56/60 + 20/3600);

wvpk = [420, 450, 470, 500, 532, 550, 605, 640, 675, 750, 778, 862, 934, 943, 953, 1024, 1040];

load 'data\f26\coord.mat' crd
ps = find(crd(:,1)==7001);
RA = crd(ps(1),2)*15;
DEC = crd(ps(1),3);

% STP %%%%%%%%%%%%%%%%%%%%%%%%%%%
load 'data\f26\wavcals.mat' c wav WL
wavi = [350:0.01:wav(end)];

load 'data\f26\tauB.mat'
% wavB tauB  CBi CB
ps = find(~isnan(tauB));
taui = interp1(wavB(ps),tauB(ps),wavi,meth,nan);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% correct satellite Vega flux and wavelengths
load 'data\f26\wavsats.mat' csat wsat fveg
wavhst = wsat;
veghst = fveg;
% wavhst = wavlib;

hst = interp1(wavhst,veghst,wavi,meth,nan);
M0h = -2.5*log10(hst')-2.5;

% high resolution positions to fit and remove continuum
ix = [  2600
        3450
        5304
        7007
        9427
       10132
       11332
       16037
       17482
       18632
       19934
       21202
       22252
       23252
       24452
       25632
       27957
       29057
       32928
       34470
       35574
       41833
       43382
       49047
       51024
       51830
       52918
       54312
       56193
       58740
       62807
       68720
       70758
       76482];

vmci = interp1(wavi(ix),M0h(ix),wavi,meth,'extrap'); % continuum
Hs = (M0h-vmci')/1.6; % abs spectrum at air mass 1.6


%%%% LAB %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% get water vapor --------------------
load data\f26\kh2o.mat 
% wwv kwv
kwv = kwv082;
% repair spectrum at change of band
dk = kwv(4151)-kwv(4152);
kwv(4152:end) = kwv(4152:end) + dk;
% odwv = 0.2*(2*kwv).^(1/1.7); % OD for 1.2 mm PWV
odwv = 0.8*kwv;

% get ozone ------------------
load data\f26\ko3.mat 
% woz koz
koz = koz082;
odoz = koz/1000*250; % for 180 DU

% get O2 --------------------
load data\f26\kox.mat
% wox kox
kox = kox082;

% repair kox at negative values
mx1 = max(kox);
dk = kox(4151)-kox(4152);
kox(4152:end) = kox(4152:end) + dk;
kox(1:3100) = 0;
kox(5070:end) = 0;

kox(1:3100) = nan;
kox(5030:end) = nan;
kox(kox<0) = 0;
kox = kox-min(kox);
pso = find(kox>0);
kox = interp1(wox([1000,pso,7000]),[0, kox(pso),0],wox,'pchip',0);
kox = kox * mx1 / max(kox);
kox = 3.05*kox.^(1.065);

odox = kox./max(kox)*0.36; % to match measured O2 line

% fit trace gas at our wavelengths
koz = interp1(woz,odoz,wavi);
kwv = interp1(wwv,odwv,wavi);
kox = interp1(wox,odox,wavi);
koz(isnan(koz)) = 0;
kwv(isnan(kwv)) = 0;
kox(isnan(kox)) = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% cumulative merit function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
kox(kox<0) = 0;
mfct2 = kwv+kox+Hs';

% new channel px found here %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
px = [1 25+2 56 82 124 151+13 185 234 271 301 346 392 436 497-18 566 611 686 689 757 799];
WLp = c(1) + c(2)*px + c(3)*px.^2 + c(4)*px.^3; % their central wavelength
WLp'

% airglow and aurora spectrum %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
load 'data\f26\airaurerr.mat' wgl egl wau eau
egl = 10*egl; % 10x larger airglow (as measured in Eureka in section Night Spectrum)
ps = find(~isnan(egl)); 
egli = interp1(wgl(ps),egl(ps),wavi,'linear','extrap')';
ps = find(~isnan(eau)); 
eaui = interp1(wau(ps),eau(ps),wavi)';
egli(isnan(egli) | egli<0) = 0;
eaui(isnan(eaui)) = 0;
eems = (egli+eaui)/1; % cumulative emission error

% make an aerosol fine and coarse spectrum to match the measurement
a = -1.3;
b = 0.022;
aerspc = b*(wavi/1000).^a + 0.05;

% intervals
Hsi = ones(size(Hs));
Hsi(abs(Hs+eems)<0.007) = nan;

%%%%%%%%%%%%% plot %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(66)
clf reset

% margins:        Nv,Nh,[dh,dw],[dn,up],[lft,rgt] 
ha = tight_subplot(2,1,[.02 .2],[.115 .005],[.07 .007]);

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'centimeters');
width = 21; height = 10; left = 0; bottom = 0;
set(gcf, 'PaperSize',[left*2+width bottom*2+height]);
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);
set(gcf, 'Units', 'centimeters');
set(gcf, 'Position', myfiguresize);

axes(ha(1));
set(gca,'FontSize',fontsz)

semilogy(wavi,koz'+kwv'+kox'+Hs,':','Color',colororder(2,:)','LineWidth',2)
hold on

semilogy(wavi,Hs,'k','LineWidth',1)
semilogy(wavi,abs(eems),'-','Color',colororder(13,:)','LineWidth',1)

semilogy(wavi,kwv,'m','LineWidth',1)
semilogy(wavi,koz,'b','LineWidth',1)
semilogy(wavi,kox,'r','LineWidth',1)

% intervals
semilogy(wavi,Hsi*2.25*1e-3,'-r','LineWidth',5)
semilogy([WLp(1) WLp(1)],[2e-3 0.37]*nan,'k','LineWidth',1.2) % 4 legend
semilogy([wvpk(1) wvpk(1)],[2e-3 0.37]*nan,'--','Color',colororder(10,:)','LineWidth',0.5) % 4 legend
for i=1:length(WLp)
    semilogy([WLp(i) WLp(i)],[2e-3 0.37],'k','LineWidth',1.2)
end
for i=1:length(wvpk)
    semilogy([wvpk(i) wvpk(i)],[2e-3 0.37],'--','Color',colororder(10,:)','LineWidth',0.5)
end
hold off
set(gca,'XLim',[380 1110],'YLim',[2e-3 0.37])
set(gca, 'YGrid', 'on', 'XGrid', 'off')

hh = legend('synth.','star (H)','airglow $\&$ aurora','$H_2O$','$O_3$','$O_2$','avoid','new','old','location','northwest','orientation','horizontal');
hh.ItemTokenSize = [30,18]/3; % default x1=30 and x2=18
set(hh,'FontSize',fontsz,'Interpreter','latex')

lgps = get(hh,'position');
lgps(1) = lgps(1)-0.008;
lgps(2) = lgps(2)+0.03;
set(hh,'position',lgps)

text(1080,0.2,'a)','FontSize',fontsz+2)
set(gca,'XTick',[400:50:1100])
grid on

daty = ylabel('Absorption $\tau$','Interpreter','latex');
set(gca,'FontName','times','FontSize',fontsz)
set(gca,'XTickLabel',{})


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
axes(ha(2));
set(gca,'FontSize',fontsz)

plot(wavi,koz'+kwv'+kox'+aerspc','-m','LineWidth',1)
hold on
plot(wavi,koz'+kwv'+kox'+Hs+aerspc',':','Color',colororder(2,:)','LineWidth',2)

plot(wavi,taui,'b','LineWidth',1)

plot([WLp(1) WLp(1)],[2e-3 0.37]*nan,'k','LineWidth',1.2) % 4 legend
plot([wvpk(1) wvpk(1)],[2e-3 0.37]*nan,'--','Color',colororder(10,:)','LineWidth',0.5) % 4 legend

for i=1:length(WLp)
    plot([WLp(i) WLp(i)],[0.07 0.30],'k','LineWidth',1.2)
end
for i=1:length(wvpk)
    plot([wvpk(i) wvpk(i)],[0.02 0.30],'--','Color',colororder(10,:)','LineWidth',0.5)
end
plot(WLp([[1:16],[19:end]]),ones(size(WLp([[1:16],[19:end]])))*(0.18+0.04),'ok','LineWidth',1,'MarkerSize',16,'MarkerFaceColor','w')
plot(WLp(17),ones(size(WLp(17)))*(0.18-0.04),'ok','LineWidth',1,'MarkerSize',16,'MarkerFaceColor','w')
plot(WLp(18),ones(size(WLp(18)))*(0.157-0.04),'ok','LineWidth',1,'MarkerSize',16,'MarkerFaceColor','w')

for i=1:16
    text(WLp(i)-7,(0.178+0.04),num2str(i,'%02d'),'color','k','Interpreter','latex')
end
text(WLp(17)-7,(0.178-0.04),num2str(17,'%02d'),'color','k','Interpreter','latex')
text(WLp(18)-7,(0.155-0.04),num2str(18,'%02d'),'color','k','Interpreter','latex')
for i=19:20
    text(WLp(i)-7,(0.178+0.04),num2str(i,'%02d'),'color','k','Interpreter','latex')
end

hold off

set(gca,'XLim',[380 1110],'YLim',[0.07 0.30])
set(gca, 'YGrid', 'on', 'XGrid', 'off')

hh = legend('(synth. w/o star)','(synth. + star)','measured','new channels','old channels','location','northwest','orientation','horizontal');
hh.ItemTokenSize = [30,18]/3; % default x1=30 and x2=18
set(hh,'FontSize',fontsz,'Interpreter','latex')

lgps = get(hh,'position');
lgps(1) = lgps(1)-0.008;
lgps(2) = lgps(2)+0.03;
set(hh,'position',lgps)

text(1080,0.27,'b)','FontSize',fontsz+2)

xlabel('Wavelength (nm)','Interpreter','latex')
daty = ylabel('Total $\tau$','Interpreter','latex');

annotation('arrow',[0.307 0.307]+0.010,[0.2 0.34]-0.1,'color','k');
annotation('arrow',[0.383 0.383]+0.001,[0.2 0.32]-0.1,'color','k');

text(577.2-6,0.03,'$O_4$','color','k','Interpreter','latex')
text(630.0-6,0.03,'$O_4$','color','k','Interpreter','latex')

set(gca,'XTick',[400:50:1100])
grid on

set(gca,'FontName','times','FontSize',fontsz)

outfile2 = strcat('pics/png/fig26');
outfile5 = strcat('pics/pdf/fig26');

if flg
    print('-dpng', '-r300', [outfile2,'.png'])
    print('-Painters','-dpdf', '-r400', [outfile5,'.pdf'])
end


